Octopus Sensing Processing
==========================

Octopus Sensing Processing is a real-time data processing for [Octopus Sensing](https://octopus-sensing.nastaran-saffar.me/). 
It can be used for processing data in real-time. You can define your favorite processor and process your data in real-time and publish the processing result. For example if you define an emotion recognition processor, Octopus Sensing Processing can prepare the input of your processor in real-time and publish your created prediction by streaming them as json data or other applications could send a request for receiving them when they needed the processing result.

[Octopus Sensing Processing](https://github.com/octopus-sensing/octopus-sensing-processing) is 
a separated project and can be installed if we need to process data in realtime. 

**To see the full documentation go to [Otopus Sensing](https://octopus-sensing.nastaran-saffar.me/processing) website.**

Copyright
---------

Copyright © 2022 [Nastaran Saffaryazdi]

This program is free software: you can redistribute it and/or modify it under the terms of the GNU
General Public License as published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

See [License file](https://github.com/octopus-sensing/octopus-sensing/blob/master/LICENSE)  for full terms.